@@ -1,27 +1,28 @@
 package App::Prove;
 
 use strict;
-use vars qw($VERSION @ISA);
+use warnings;
 
-use TAP::Object ();
-use TAP::Harness;
-use TAP::Parser::Utils qw( split_shell );
+use TAP::Harness::Env;
+use Text::ParseWords qw(shellwords);
 use File::Spec;
 use Getopt::Long;
 use App::Prove::State;
 use Carp;
 
+use base 'TAP::Object';
+
 =head1 NAME
 
 App::Prove - Implements the C<prove> command.
 
 =head1 VERSION
 
-Version 3.17_04
+Version 3.37_01
 
 =cut
 
-$VERSION = '3.17_04';
+our $VERSION = '3.37_01';
 
 =head1 DESCRIPTION
 
@@ -51,15 +52,13 @@ use constant PLUGINS => 'App::Prove::Plugin';
 my @ATTR;
 
 BEGIN {
-    @ISA = qw(TAP::Object);
-
     @ATTR = qw(
       archive argv blib show_count color directives exec failures comments
       formatter harness includes modules plugins jobs lib merge parse quiet
       really_quiet recurse backwards shuffle taint_fail taint_warn timer
       verbose warnings_fail warnings_warn show_help show_man show_version
-      state_class test_args state dry extension ignore_exit rules state_manager
-      normalize sources
+      state_class test_args state dry extensions ignore_exit rules state_manager
+      normalize sources tapversion trap
     );
     __PACKAGE__->mk_methods(@ATTR);
 }
@@ -81,13 +80,14 @@ sub _initialize {
     my $self = shift;
     my $args = shift || {};
 
+    my @is_array = qw(
+      argv rc_opts includes modules state plugins rules sources
+    );
+
     # setup defaults:
-    for my $key (
-        qw( argv rc_opts includes modules state plugins rules sources ))
-    {
+    for my $key (@is_array) {
         $self->{$key} = [];
     }
-    $self->{harness_class} = 'TAP::Harness';
 
     for my $attr (@ATTR) {
         if ( exists $args->{$attr} ) {
@@ -97,13 +97,6 @@ sub _initialize {
         }
     }
 
-    my %env_provides_default = (
-        HARNESS_TIMER => 'timer',
-    );
-
-    while ( my ( $env, $attr ) = each %env_provides_default ) {
-        $self->{$attr} = 1 if $ENV{$env};
-    }
     $self->state_class('App::Prove::State');
     return $self;
 }
@@ -203,46 +196,54 @@ sub process_args {
 
         # Don't add coderefs to GetOptions
         GetOptions(
-            'v|verbose'   => \$self->{verbose},
-            'f|failures'  => \$self->{failures},
-            'o|comments'  => \$self->{comments},
-            'l|lib'       => \$self->{lib},
-            'b|blib'      => \$self->{blib},
-            's|shuffle'   => \$self->{shuffle},
-            'color!'      => \$self->{color},
-            'colour!'     => \$self->{color},
-            'count!'      => \$self->{show_count},
-            'c'           => \$self->{color},
-            'D|dry'       => \$self->{dry},
-            'ext=s'       => \$self->{extension},
-            'harness=s'   => \$self->{harness},
-            'ignore-exit' => \$self->{ignore_exit},
-            'source=s@'   => $self->{sources},
-            'formatter=s' => \$self->{formatter},
-            'r|recurse'   => \$self->{recurse},
-            'reverse'     => \$self->{backwards},
-            'p|parse'     => \$self->{parse},
-            'q|quiet'     => \$self->{quiet},
-            'Q|QUIET'     => \$self->{really_quiet},
-            'e|exec=s'    => \$self->{exec},
-            'm|merge'     => \$self->{merge},
-            'I=s@'        => $self->{includes},
-            'M=s@'        => $self->{modules},
-            'P=s@'        => $self->{plugins},
-            'state=s@'    => $self->{state},
-            'directives'  => \$self->{directives},
-            'h|help|?'    => \$self->{show_help},
-            'H|man'       => \$self->{show_man},
-            'V|version'   => \$self->{show_version},
-            'a|archive=s' => \$self->{archive},
-            'j|jobs=i'    => \$self->{jobs},
-            'timer'       => \$self->{timer},
-            'T'           => \$self->{taint_fail},
-            't'           => \$self->{taint_warn},
-            'W'           => \$self->{warnings_fail},
-            'w'           => \$self->{warnings_warn},
-            'normalize'   => \$self->{normalize},
-            'rules=s@'    => $self->{rules},
+            'v|verbose'  => \$self->{verbose},
+            'f|failures' => \$self->{failures},
+            'o|comments' => \$self->{comments},
+            'l|lib'      => \$self->{lib},
+            'b|blib'     => \$self->{blib},
+            's|shuffle'  => \$self->{shuffle},
+            'color!'     => \$self->{color},
+            'colour!'    => \$self->{color},
+            'count!'     => \$self->{show_count},
+            'c'          => \$self->{color},
+            'D|dry'      => \$self->{dry},
+            'ext=s@'     => sub {
+                my ( $opt, $val ) = @_;
+
+                # Workaround for Getopt::Long 2.25 handling of
+                # multivalue options
+                push @{ $self->{extensions} ||= [] }, $val;
+            },
+            'harness=s'    => \$self->{harness},
+            'ignore-exit'  => \$self->{ignore_exit},
+            'source=s@'    => $self->{sources},
+            'formatter=s'  => \$self->{formatter},
+            'r|recurse'    => \$self->{recurse},
+            'reverse'      => \$self->{backwards},
+            'p|parse'      => \$self->{parse},
+            'q|quiet'      => \$self->{quiet},
+            'Q|QUIET'      => \$self->{really_quiet},
+            'e|exec=s'     => \$self->{exec},
+            'm|merge'      => \$self->{merge},
+            'I=s@'         => $self->{includes},
+            'M=s@'         => $self->{modules},
+            'P=s@'         => $self->{plugins},
+            'state=s@'     => $self->{state},
+            'directives'   => \$self->{directives},
+            'h|help|?'     => \$self->{show_help},
+            'H|man'        => \$self->{show_man},
+            'V|version'    => \$self->{show_version},
+            'a|archive=s'  => \$self->{archive},
+            'j|jobs=i'     => \$self->{jobs},
+            'timer'        => \$self->{timer},
+            'T'            => \$self->{taint_fail},
+            't'            => \$self->{taint_warn},
+            'W'            => \$self->{warnings_fail},
+            'w'            => \$self->{warnings_warn},
+            'normalize'    => \$self->{normalize},
+            'rules=s@'     => $self->{rules},
+            'tapversion=s' => \$self->{tapversion},
+            'trap'         => \$self->{trap},
         ) or croak('Unable to continue');
 
         # Stash the remainder of argv for later
@@ -286,6 +287,8 @@ sub _get_args {
 
     my %args;
 
+    $args{trap} = 1 if $self->trap;
+
     if ( defined $self->color ? $self->color : $self->_color_default ) {
         $args{color} = 1;
     }
@@ -313,7 +316,7 @@ sub _get_args {
         $args{formatter_class} = $formatter;
     }
 
-    foreach my $handler ( @{ $self->sources } ) {
+    for my $handler ( @{ $self->sources } ) {
         my ( $name, $config ) = $self->_parse_source($handler);
         $args{sources}->{$name} = $config;
     }
@@ -357,6 +360,8 @@ sub _get_args {
     $args{exec} = [ split( /\s+/, $self->exec ) ]
       if ( defined( $self->exec ) );
 
+    $args{version} = $self->tapversion if defined( $self->tapversion );
+
     if ( defined( my $test_args = $self->test_args ) ) {
         $args{test_args} = $test_args;
     }
@@ -373,8 +378,9 @@ sub _get_args {
         }
         $args{rules} = { par => [@rules] };
     }
+    $args{harness_class} = $self->{harness_class} if $self->{harness_class};
 
-    return ( \%args, $self->{harness_class} );
+    return \%args;
 }
 
 sub _find_module {
@@ -428,14 +434,26 @@ sub _parse_source {
     my %config;
     Getopt::Long::GetOptions(
         "$opt_name-option=s%" => sub {
-            my ( undef, $k, $v ) = @_;
-            if ( exists $config{$k} ) {
-                $config{$k} = [ $config{$k} ]
-                  unless ref $config{$k} eq 'ARRAY';
-                push @{ $config{$k} } => $v;
+            my ( $name, $k, $v ) = @_;
+            if ( $v =~ /(?<!\\)=/ ) {
+
+                # It's a hash option.
+                croak "Option $name must be consistently used as a hash"
+                  if exists $config{$k} && ref $config{$k} ne 'HASH';
+                $config{$k} ||= {};
+                my ( $hk, $hv ) = split /(?<!\\)=/, $v, 2;
+                $config{$k}{$hk} = $hv;
             }
             else {
-                $config{$k} = $v;
+                $v =~ s/\\=/=/g;
+                if ( exists $config{$k} ) {
+                    $config{$k} = [ $config{$k} ]
+                      unless ref $config{$k} eq 'ARRAY';
+                    push @{ $config{$k} } => $v;
+                }
+                else {
+                    $config{$k} = $v;
+                }
             }
         }
     );
@@ -493,8 +511,8 @@ sub _get_tests {
     my $self = shift;
 
     my $state = $self->state_manager;
-    my $ext   = $self->extension;
-    $state->extension($ext) if defined $ext;
+    my $ext   = $self->extensions;
+    $state->extensions($ext) if defined $ext;
     if ( defined( my $state_switch = $self->state ) ) {
         $state->apply_switch(@$state_switch);
     }
@@ -508,8 +526,8 @@ sub _get_tests {
 }
 
 sub _runtests {
-    my ( $self, $args, $harness_class, @tests ) = @_;
-    my $harness = $harness_class->new($args);
+    my ( $self, $args, @tests ) = @_;
+    my $harness = TAP::Harness::Env->create($args);
 
     my $state = $self->state_manager;
 
@@ -548,8 +566,6 @@ sub _get_switches {
         push @switches, '-w';
     }
 
-    push @switches, split_shell( $ENV{HARNESS_PERL_SWITCHES} );
-
     return @switches ? \@switches : ();
 }
 
@@ -618,6 +634,7 @@ current Perl.
 
 sub print_version {
     my $self = shift;
+    require TAP::Harness;
     printf(
         "TAP::Harness v%s and Perl v%vd\n",
         $TAP::Harness::VERSION, $^V
@@ -656,7 +673,7 @@ calling C<run>.
 
 =item C<exec>
 
-=item C<extension>
+=item C<extensions>
 
 =item C<failures>
 
@@ -718,6 +735,10 @@ calling C<run>.
 
 =item C<warnings_warn>
 
+=item C<tapversion>
+
+=item C<trap>
+
 =back
 
 =head1 PLUGINS
