@@ -1,7 +1,7 @@
 package App::Prove::State;
 
 use strict;
-use vars qw($VERSION @ISA);
+use warnings;
 
 use File::Find;
 use File::Spec;
@@ -10,10 +10,9 @@ use Carp;
 use App::Prove::State::Result;
 use TAP::Parser::YAMLish::Reader ();
 use TAP::Parser::YAMLish::Writer ();
-use TAP::Base;
+use base 'TAP::Base';
 
 BEGIN {
-    @ISA = qw( TAP::Base );
     __PACKAGE__->mk_methods('result_class');
 }
 
@@ -26,11 +25,11 @@ App::Prove::State - State storage for the C<prove> command.
 
 =head1 VERSION
 
-Version 3.17_04
+Version 3.37_01
 
 =cut
 
-$VERSION = '3.17_04';
+our $VERSION = '3.37_01';
 
 =head1 DESCRIPTION
 
@@ -41,7 +40,7 @@ and the operations that may be performed on it.
 =head1 SYNOPSIS
 
     # Re-run failed tests
-    $ prove --state=fail,save -rbv
+    $ prove --state=failed,save -rbv
 
 =cut
 
@@ -59,9 +58,9 @@ Accepts a hashref with the following key/value pairs:
 
 The filename of the data store holding the data that App::Prove::State reads.
 
-=item * C<extension> (optional)
+=item * C<extensions> (optional)
 
-The test name extension.  Defaults to C<.t>.
+The test name extensions.  Defaults to C<.t>.
 
 =item * C<result_class> (optional)
 
@@ -77,10 +76,10 @@ sub new {
     my %args = %{ shift || {} };
 
     my $self = bless {
-        select    => [],
-        seq       => 1,
-        store     => delete $args{store},
-        extension => ( delete $args{extension} || '.t' ),
+        select     => [],
+        seq        => 1,
+        store      => delete $args{store},
+        extensions => ( delete $args{extensions} || ['.t'] ),
         result_class =>
           ( delete $args{result_class} || 'App::Prove::State::Result' ),
     }, $class;
@@ -105,17 +104,17 @@ identical interface.
 
 =cut
 
-=head2 C<extension>
+=head2 C<extensions>
 
-Get or set the extension files must have in order to be considered
-tests. Defaults to '.t'.
+Get or set the list of extensions that files must have in order to be
+considered tests. Defaults to ['.t'].
 
 =cut
 
-sub extension {
+sub extensions {
     my $self = shift;
-    $self->{extension} = shift if @_;
-    return $self->{extension};
+    $self->{extensions} = shift if @_;
+    return $self->{extensions};
 }
 
 =head2 C<results>
@@ -217,48 +216,70 @@ sub apply_switch {
     my %handler = (
         last => sub {
             $self->_select(
+                limit => shift,
                 where => sub { $_->generation >= $last_gen },
                 order => sub { $_->sequence }
             );
         },
         failed => sub {
             $self->_select(
+                limit => shift,
                 where => sub { $_->result != 0 },
                 order => sub { -$_->result }
             );
         },
         passed => sub {
-            $self->_select( where => sub { $_->result == 0 } );
+            $self->_select(
+                limit => shift,
+                where => sub { $_->result == 0 }
+            );
         },
         all => sub {
-            $self->_select();
+            $self->_select( limit => shift );
         },
         todo => sub {
             $self->_select(
+                limit => shift,
                 where => sub { $_->num_todo != 0 },
                 order => sub { -$_->num_todo; }
             );
         },
         hot => sub {
             $self->_select(
+                limit => shift,
                 where => sub { defined $_->last_fail_time },
                 order => sub { $now - $_->last_fail_time }
             );
         },
         slow => sub {
-            $self->_select( order => sub { -$_->elapsed } );
+            $self->_select(
+                limit => shift,
+                order => sub { -$_->elapsed }
+            );
         },
         fast => sub {
-            $self->_select( order => sub { $_->elapsed } );
+            $self->_select(
+                limit => shift,
+                order => sub { $_->elapsed }
+            );
         },
         new => sub {
-            $self->_select( order => sub { -$_->mtime } );
+            $self->_select(
+                limit => shift,
+                order => sub { -$_->mtime }
+            );
         },
         old => sub {
-            $self->_select( order => sub { $_->mtime } );
+            $self->_select(
+                limit => shift,
+                order => sub { $_->mtime }
+            );
         },
         fresh => sub {
-            $self->_select( where => sub { $_->mtime >= $last_run_time } );
+            $self->_select(
+                limit => shift,
+                where => sub { $_->mtime >= $last_run_time }
+            );
         },
         save => sub {
             $self->{should_save}++;
@@ -345,6 +366,10 @@ sub _query_clause {
           } @got;
     }
 
+    if ( my $limit = $clause->{limit} ) {
+        @got = splice @got, 0, $limit if @got > $limit;
+    }
+
     return @got;
 }
 
@@ -355,8 +380,11 @@ sub _get_raw_tests {
     my @tests;
 
     # Do globbing on Win32.
-    @argv = map { glob "$_" } @argv if NEED_GLOB;
-    my $extension = $self->{extension};
+    if (NEED_GLOB) {
+        eval "use File::Glob::Windows";    # [49732]
+        @argv = map { glob "$_" } @argv;
+    }
+    my $extensions = $self->{extensions};
 
     for my $arg (@argv) {
         if ( '-' eq $arg ) {
@@ -368,23 +396,26 @@ sub _get_raw_tests {
         push @tests,
             sort -d $arg
           ? $recurse
-              ? $self->_expand_dir_recursive( $arg, $extension )
-              : glob( File::Spec->catfile( $arg, "*$extension" ) )
+              ? $self->_expand_dir_recursive( $arg, $extensions )
+              : map { glob( File::Spec->catfile( $arg, "*$_" ) ) }
+              @{$extensions}
           : $arg;
     }
     return @tests;
 }
 
 sub _expand_dir_recursive {
-    my ( $self, $dir, $extension ) = @_;
+    my ( $self, $dir, $extensions ) = @_;
 
     my @tests;
+    my $ext_string = join( '|', map {quotemeta} @{$extensions} );
+
     find(
         {   follow      => 1,      #21938
             follow_skip => 2,
             wanted      => sub {
                 -f 
-                  && /\Q$extension\E$/
+                  && /(?:$ext_string)$/
                   && push @tests => $File::Find::name;
               }
         },
