@@ -1,15 +1,14 @@
 package TAP::Formatter::Console::ParallelSession;
 
 use strict;
+use warnings;
 use File::Spec;
 use File::Path;
-use TAP::Formatter::Console::Session;
 use Carp;
 
-use constant WIDTH => 72;    # Because Eric says
-use vars qw($VERSION @ISA);
+use base 'TAP::Formatter::Console::Session';
 
-@ISA = qw(TAP::Formatter::Console::Session);
+use constant WIDTH => 72;    # Because Eric says
 
 my %shared;
 
@@ -42,11 +41,11 @@ TAP::Formatter::Console::ParallelSession - Harness output delegate for parallel
 
 =head1 VERSION
 
-Version 3.17_04
+Version 3.37_01
 
 =cut
 
-$VERSION = '3.17_04';
+our $VERSION = '3.37_01';
 
 =head1 DESCRIPTION
 
@@ -94,7 +93,7 @@ sub _output_ruler {
 
     my $ruler = sprintf '===( %7d;%d  ', $context->{tests}, $now - $start;
 
-    foreach my $active ( @{ $context->{active} } ) {
+    for my $active ( @{ $context->{active} } ) {
         my $parser  = $active->parser;
         my $tests   = $parser->tests_run;
         my $planned = $parser->tests_planned || '?';
