@@ -1,11 +1,9 @@
 package TAP::Formatter::Console::Session;
 
 use strict;
-use TAP::Formatter::Session;
+use warnings;
 
-use vars qw($VERSION @ISA);
-
-@ISA = qw(TAP::Formatter::Session);
+use base 'TAP::Formatter::Session';
 
 my @ACCESSOR;
 
@@ -28,11 +26,11 @@ TAP::Formatter::Console::Session - Harness output delegate for default console o
 
 =head1 VERSION
 
-Version 3.17_04
+Version 3.37_01
 
 =cut
 
-$VERSION = '3.17_04';
+our $VERSION = '3.37_01';
 
 =head1 DESCRIPTION
 
@@ -187,20 +185,8 @@ sub _closures {
                 $self->_output_test_failure($parser);
             }
             else {
-                my $time_report = '';
-                if ( $formatter->timer ) {
-                    my $start_time = $parser->start_time;
-                    my $end_time   = $parser->end_time;
-                    if ( defined $start_time and defined $end_time ) {
-                        my $elapsed = $end_time - $start_time;
-                        $time_report
-                          = $self->time_is_hires
-                          ? sprintf( ' %8d ms', $elapsed * 1000 )
-                          : sprintf( ' %8s s', $elapsed || '<1' );
-                    }
-                }
-
-                $formatter->_output("ok$time_report\n");
+                my $time_report = $self->time_report($formatter, $parser);
+                $formatter->_output( $self->_make_ok_line($time_report) );
             }
         },
     };
