@@ -1,9 +1,8 @@
 package TAP::Parser;
 
 use strict;
-use vars qw($VERSION @ISA);
+use warnings;
 
-use TAP::Base                              ();
 use TAP::Parser::Grammar                   ();
 use TAP::Parser::Result                    ();
 use TAP::Parser::ResultFactory             ();
@@ -18,17 +17,21 @@ use TAP::Parser::SourceHandler::Handle     ();
 
 use Carp qw( confess );
 
+use base 'TAP::Base';
+
+=encoding utf8
+
 =head1 NAME
 
 TAP::Parser - Parse L<TAP|Test::Harness::TAP> output
 
 =head1 VERSION
 
-Version 3.17_04
+Version 3.37_01
 
 =cut
 
-$VERSION = '3.17_04';
+our $VERSION = '3.37_01';
 
 my $DEFAULT_TAP_VERSION = 12;
 my $MAX_TAP_VERSION     = 13;
@@ -42,8 +45,6 @@ END {
 }
 
 BEGIN {    # making accessors
-    @ISA = qw(TAP::Base);
-
     __PACKAGE__->mk_methods(
         qw(
           _iterator
@@ -59,6 +60,8 @@ BEGIN {    # making accessors
           in_todo
           start_time
           end_time
+          start_times
+          end_times
           skip_all
           grammar_class
           result_factory_class
@@ -94,7 +97,7 @@ L<http://testanything.org>
 
 It includes the TAP::Parser Cookbook:
 
-L<http://testanything.org/wiki/index.php/TAP::Parser_Cookbook>
+L<http://testanything.org/testing-with-tap/perl/tap::parser-cookbook.html>
 
 =head1 METHODS
 
@@ -174,7 +177,7 @@ I<NEW to 3.18>.
 
 If set, C<sources> must be a hashref containing the names of the
 L<TAP::Parser::SourceHandler>s to load and/or configure.  The values are a
-hash of configuration that will be accessible to to the source handlers via
+hash of configuration that will be accessible to the source handlers via
 L<TAP::Parser::Source/config_for>.
 
 For example:
@@ -210,7 +213,7 @@ with the result as the argument if the C<run> method is used:
  );
 
  my $aggregator = TAP::Parser::Aggregator->new;
- foreach my $file ( @test_files ) {
+ for my $file ( @test_files ) {
      my $parser = TAP::Parser->new(
          {
              source    => $file,
@@ -370,9 +373,7 @@ sub make_result           { shift->result_factory_class->make_result(@_); }
     my %initialize = (
         version       => $DEFAULT_TAP_VERSION,
         plan          => '',                    # the test plan (e.g., 1..3)
-        tap           => '',                    # the TAP
         tests_run     => 0,                     # actual current test numbers
-        results       => [],                    # TAP parser results
         skipped       => [],                    #
         todo          => [],                    #
         passed        => [],                    #
@@ -425,6 +426,7 @@ sub make_result           { shift->result_factory_class->make_result(@_); }
         my $iterator = delete $args{iterator};
         $iterator ||= delete $args{stream};    # deprecated
         my $tap         = delete $args{tap};
+        my $version     = delete $args{version};
         my $raw_source  = delete $args{source};
         my $sources     = delete $args{sources};
         my $exec        = delete $args{exec};
@@ -453,7 +455,7 @@ sub make_result           { shift->result_factory_class->make_result(@_); }
         }
         elsif ($exec) {
             $type = 'exec ' . $exec->[0];
-            $source->raw( { exec => [ @$exec, @$test_args ] } );
+            $source->raw( { exec => $exec } );
         }
         elsif ($raw_source) {
             $type = 'source ' . ref($raw_source) || $raw_source;
@@ -479,6 +481,7 @@ sub make_result           { shift->result_factory_class->make_result(@_); }
             $self->{$k} = 'ARRAY' eq ref $v ? [] : $v;
         }
 
+        $self->version($version) if $version;
         $self->_iterator($iterator);
         $self->_spool($spool);
         $self->ignore_exit($ignore_exit);
@@ -638,8 +641,8 @@ C<$result> object.
 
 Returns a list of pragmas each of which is a + or - followed by the
 pragma name.
- 
-=head2 C<commment> methods
+
+=head2 C<comment> methods
 
  if ( $result->is_comment ) { ... }
 
@@ -716,7 +719,7 @@ line.
   my $explanation = $result->explanation;
 
 If a test had either a C<TODO> or C<SKIP> directive, this method will return
-the accompanying explantion, if present.
+the accompanying explanation, if present.
 
   not ok 17 - 'Pigs can fly' # TODO not enough acid
 
@@ -795,7 +798,11 @@ but had a TODO directive, it will be counted as a passed test.
 
 =cut
 
-sub passed { @{ shift->{passed} } }
+sub passed {
+    return @{ $_[0]->{passed} }
+      if ref $_[0]->{passed};
+    return wantarray ? 1 .. $_[0]->{passed} : $_[0]->{passed};
+}
 
 =head3 C<failed>
 
@@ -822,7 +829,11 @@ regardless of whether or not a TODO directive was found.
 
 =cut
 
-sub actual_passed { @{ shift->{actual_passed} } }
+sub actual_passed {
+    return @{ $_[0]->{actual_passed} }
+      if ref $_[0]->{actual_passed};
+    return wantarray ? 1 .. $_[0]->{actual_passed} : $_[0]->{actual_passed};
+}
 *actual_ok = \&actual_passed;
 
 =head3 C<actual_ok>
@@ -998,11 +1009,20 @@ were skipped.
 
 =head3 C<start_time>
 
-Returns the time when the Parser was created.
+Returns the wall-clock time when the Parser was created.
 
 =head3 C<end_time>
 
-Returns the time when the end of TAP input was seen.
+Returns the wall-clock time when the end of TAP input was seen.
+
+=head3 C<start_times>
+
+Returns the CPU times (like L<perlfunc/times> when the Parser was created.
+
+=head3 C<end_times>
+
+Returns the CPU times (like L<perlfunc/times> when the end of TAP
+input was seen.
 
 =head3 C<has_problems>
 
@@ -1044,7 +1064,7 @@ an executable, it returns the exit status of the executable.
 
 Once the parser is done, this will return the wait status.  If the parser ran
 an executable, it returns the wait status of the executable.  Otherwise, this
-mererely returns the C<exit> status.
+merely returns the C<exit> status.
 
 =head2 C<ignore_exit>
 
@@ -1309,7 +1329,7 @@ sub _make_state_table {
         UNPLANNED_AFTER_TEST => {
             test => { act  => sub { }, continue => 'UNPLANNED' },
             plan => { act  => sub { }, continue => 'UNPLANNED' },
-            yaml => { goto => 'PLANNED' },
+            yaml => { goto => 'UNPLANNED' },
         },
     );
 
@@ -1365,6 +1385,7 @@ sub _iter {
     my $state_table = $self->_make_state_table;
 
     $self->start_time( $self->get_time );
+    $self->start_times( $self->get_times );
 
     # Make next_state closure
     my $next_state = sub {
@@ -1457,6 +1478,7 @@ sub _finish {
     my $self = shift;
 
     $self->end_time( $self->get_time );
+    $self->end_times( $self->get_times );
 
     # Avoid leaks
     $self->_iterator(undef);
@@ -1496,6 +1518,17 @@ sub _finish {
     }
 
     $self->is_good_plan(0) unless defined $self->is_good_plan;
+
+    unless ( $self->parse_errors ) {
+        # Optimise storage where possible
+        if ( $self->tests_run == @{$self->{passed}} ) {
+            $self->{passed} = $self->tests_run;
+        }
+        if ( $self->tests_run == @{$self->{actual_passed}} ) {
+            $self->{actual_passed} = $self->tests_run;
+        }
+    }
+
     return $self;
 }
 
@@ -1533,7 +1566,7 @@ result as its argument.
  );
 
  my $aggregator = TAP::Parser::Aggregator->new;
- foreach my $file ( @test_files ) {
+ for my $file ( @test_files ) {
      my $parser = TAP::Parser->new(
          {
              source    => $file,
@@ -1636,9 +1669,9 @@ passed instead.
 
 If you're looking for an EBNF grammar, see L<TAP::Parser::Grammar>.
 
-=head1 BACKWARDS COMPATABILITY
+=head1 BACKWARDS COMPATIBILITY
 
-The Perl-QA list attempted to ensure backwards compatability with
+The Perl-QA list attempted to ensure backwards compatibility with
 L<Test::Harness>.  However, there are some minor differences.
 
 =head2 Differences
@@ -1702,22 +1735,22 @@ Many C<TAP::*> classes have a I<SUBCLASSING> section to guide you.
 
 =item 3
 
-Note that C<TAP::Parser> is designed to be the central 'maker' - ie: it is
+Note that C<TAP::Parser> is designed to be the central "maker" - ie: it is
 responsible for creating most new objects in the C<TAP::Parser::*> namespace.
 
 This makes it possible for you to have a single point of configuring what
-subclasses should be used, which in turn means that in many cases you'll find
+subclasses should be used, which means that in many cases you'll find
 you only need to sub-class one of the parser's components.
 
 The exception to this rule are I<SourceHandlers> & I<Iterators>, but those are
-both created with customizeable I<IteratorFactory>.
+both created with customizable I<IteratorFactory>.
 
 =item 4
 
 By subclassing, you may end up overriding undocumented methods.  That's not
 a bad thing per se, but be forewarned that undocumented methods may change
 without warning from one release to the next - we cannot guarantee backwards
-compatability.  If any I<documented> method needs changing, it will be
+compatibility.  If any I<documented> method needs changing, it will be
 deprecated first, and changed in a later release.
 
 =back
@@ -1727,7 +1760,7 @@ deprecated first, and changed in a later release.
 =head3 Sources
 
 A TAP parser consumes input from a single I<raw source> of TAP, which could come
-from anywhere (a file, an executable, a database, an io handle, a uri, etc..).
+from anywhere (a file, an executable, a database, an IO handle, a URI, etc..).
 The source gets bundled up in a L<TAP::Parser::Source> object which gathers some
 meta data about it.  The parser then uses a L<TAP::Parser::IteratorFactory> to
 determine which L<TAP::Parser::SourceHandler> to use to turn the raw source
@@ -1745,7 +1778,7 @@ so without sub-classing C<TAP::Parser> by setting L</iterator_factory_class>.
 If you just need to customize the objects on creation, subclass L<TAP::Parser>
 and override L</make_iterator_factory>.
 
-Note that L</make_source> & L</make_perl_source> have been I<DEPRECATED> and
+Note that C<make_source> & C<make_perl_source> have been I<DEPRECATED> and
 are now removed.
 
 =head3 Iterators
@@ -1753,7 +1786,7 @@ are now removed.
 A TAP parser uses I<iterators> to loop through the I<stream> of TAP read in
 from the I<source> it was given.  There are a few types of Iterators available
 by default, all sub-classes of L<TAP::Parser::Iterator>.  Choosing which
-iterator to use is the responsibility of the I<siterator factory>, though it
+iterator to use is the responsibility of the I<iterator factory>, though it
 simply delegates to the I<Source Handler> it uses.
 
 If you're writing your own L<TAP::Parser::SourceHandler>, you may need to
@@ -1791,7 +1824,7 @@ override L</make_result>.
 
 =head3 Grammar
 
-L<TAP::Parser::Grammar> is the heart of the parser - it tokenizes the TAP
+L<TAP::Parser::Grammar> is the heart of the parser.  It tokenizes the TAP
 input I<stream> and produces results.  If you need to customize its behaviour
 you should probably familiarize yourself with the source first.  Enough
 lecturing.
@@ -1802,7 +1835,7 @@ C<grammar_class> parameter.  See L</new> for more details.
 If you need to customize the objects on creation, subclass L<TAP::Parser> and
 override L</make_grammar>
 
-=head1 ACKNOWLEDGEMENTS
+=head1 ACKNOWLEDGMENTS
 
 All of the following have helped. Bug reports, patches, (im)moral
 support, or just words of encouragement have all been forthcoming.
@@ -1849,6 +1882,8 @@ support, or just words of encouragement have all been forthcoming.
 
 =item * Cosimo Streppone
 
+=item * Ville Skyttä
+
 =back
 
 =head1 AUTHORS
@@ -1869,6 +1904,8 @@ Nicholas Clark <nick@ccl4.org>
 
 Lee Johnson <notfadeaway at btinternet dot com>
 
+Philippe Bruhat <book@cpan.org>
+
 =head1 BUGS
 
 Please report any bugs or feature requests to
@@ -1880,7 +1917,7 @@ progress on your bug as we make changes.
 Obviously, bugs which include patches are best. If you prefer, you can
 patch against bleed by via anonymous checkout of the latest version:
 
- git clone git://github.com/AndyA/Test-Harness.git
+ git clone git://github.com/Perl-Toolchain-Gang/Test-Harness.git
 
 =head1 COPYRIGHT & LICENSE
 
