@@ -1,12 +1,10 @@
 package TAP::Parser::Aggregator;
 
 use strict;
+use warnings;
 use Benchmark;
-use vars qw($VERSION @ISA);
 
-use TAP::Object ();
-
-@ISA = qw(TAP::Object);
+use base 'TAP::Object';
 
 =head1 NAME
 
@@ -14,11 +12,11 @@ TAP::Parser::Aggregator - Aggregate TAP::Parser results
 
 =head1 VERSION
 
-Version 3.17_04
+Version 3.37_01
 
 =cut
 
-$VERSION = '3.17_04';
+our $VERSION = '3.37_01';
 
 =head1 SYNOPSIS
 
@@ -74,7 +72,7 @@ BEGIN {    # install summary methods
     $SUMMARY_METHOD_FOR{total}   = 'tests_run';
     $SUMMARY_METHOD_FOR{planned} = 'tests_planned';
 
-    foreach my $method ( keys %SUMMARY_METHOD_FOR ) {
+    for my $method ( keys %SUMMARY_METHOD_FOR ) {
         next if 'total' eq $method;
         no strict 'refs';
         *$method = sub {
@@ -90,7 +88,7 @@ sub _initialize {
     my ($self) = @_;
     $self->{parser_for}  = {};
     $self->{parse_order} = [];
-    foreach my $summary ( keys %SUMMARY_METHOD_FOR ) {
+    for my $summary ( keys %SUMMARY_METHOD_FOR ) {
         $self->{$summary} = 0;
         next if 'total' eq $summary;
         $self->{"descriptions_for_$summary"} = [];
@@ -175,7 +173,7 @@ sub parsers {
 sub _get_parsers {
     my ( $self, @descriptions ) = @_;
     my @parsers;
-    foreach my $description (@descriptions) {
+    for my $description (@descriptions) {
         $self->_croak("A parser for ($description) could not be found")
           unless exists $self->{parser_for}{$description};
         push @parsers => $self->{parser_for}{$description};
