@@ -1,27 +1,26 @@
 package TAP::Parser::Iterator::Process;
 
 use strict;
-use vars qw($VERSION @ISA);
+use warnings;
 
-use TAP::Parser::Iterator ();
 use Config;
 use IO::Handle;
 
-@ISA = 'TAP::Parser::Iterator';
+use base 'TAP::Parser::Iterator';
 
 my $IS_WIN32 = ( $^O =~ /^(MS)?Win32$/ );
 
 =head1 NAME
 
-TAP::Parser::Iterator::Process - Iterator for proccess-based TAP sources
+TAP::Parser::Iterator::Process - Iterator for process-based TAP sources
 
 =head1 VERSION
 
-Version 3.17_04
+Version 3.37_01
 
 =cut
 
-$VERSION = '3.17_04';
+our $VERSION = '3.37_01';
 
 =head1 SYNOPSIS
 
@@ -79,7 +78,8 @@ Get the exit status for this iterator's process.
 
 {
 
-    # get around a catch22 in the test suite that causes failures on Win32:
+    no warnings 'uninitialized';
+       # get around a catch22 in the test suite that causes failures on Win32:
     local $SIG{__DIE__} = undef;
     eval { require POSIX; &POSIX::WEXITSTATUS(0) };
     if ($@) {
@@ -137,7 +137,7 @@ sub _initialize {
 
         # HOTPATCH {{{
         my $xclose = \&IPC::Open3::xclose;
-        local $^W;    # no warnings
+        no warnings;
         local *IPC::Open3::xclose = sub {
             my $fh = shift;
             no strict 'refs';
@@ -157,9 +157,7 @@ sub _initialize {
             };
             die "Could not execute (@command): $@" if $@;
             if ( $] >= 5.006 ) {
-
-                # Kludge to avoid warning under 5.5
-                eval 'binmode($out, ":crlf")';
+                binmode($out, ":crlf");
             }
         }
         else {
