@@ -1,14 +1,12 @@
 package TAP::Parser::IteratorFactory;
 
 use strict;
-use vars qw($VERSION @ISA);
-
-use TAP::Object ();
+use warnings;
 
 use Carp qw( confess );
 use File::Basename qw( fileparse );
 
-@ISA = qw(TAP::Object);
+use base 'TAP::Object';
 
 use constant handlers => [];
 
@@ -18,11 +16,11 @@ TAP::Parser::IteratorFactory - Figures out which SourceHandler objects to use fo
 
 =head1 VERSION
 
-Version 3.17_04
+Version 3.37_01
 
 =cut
 
-$VERSION = '3.17_04';
+our $VERSION = '3.37_01';
 
 =head1 SYNOPSIS
 
@@ -152,7 +150,7 @@ C<croak>s on error.
 
 sub load_handlers {
     my ($self) = @_;
-    foreach my $handler ( keys %{ $self->config } ) {
+    for my $handler ( keys %{ $self->config } ) {
         my $sclass = $self->_load_handler($handler);
 
         # TODO: store which class we loaded anywhere?
@@ -164,7 +162,7 @@ sub _load_handler {
     my ( $self, $handler ) = @_;
 
     my @errors;
-    foreach my $dclass ( "TAP::Parser::SourceHandler::$handler", $handler ) {
+    for my $dclass ( "TAP::Parser::SourceHandler::$handler", $handler ) {
         return $dclass
           if UNIVERSAL::can( $dclass, 'can_handle' )
               && UNIVERSAL::can( $dclass, 'make_iterator' );
@@ -246,7 +244,7 @@ sub detect_source {
 
     # find a list of handlers that can handle this source:
     my %handlers;
-    foreach my $dclass ( @{ $self->handlers } ) {
+    for my $dclass ( @{ $self->handlers } ) {
         my $confidence = $dclass->can_handle($source);
 
         # warn "handler: $dclass: $confidence\n";
@@ -302,11 +300,8 @@ But in case you find the need to...
   package MyIteratorFactory;
 
   use strict;
-  use vars '@ISA';
 
-  use TAP::Parser::IteratorFactory;
-
-  @ISA = qw( TAP::Parser::IteratorFactory );
+  use base 'TAP::Parser::IteratorFactory';
 
   # override source detection algorithm
   sub detect_source {
