@@ -1,11 +1,9 @@
 package TAP::Parser::Result;
 
 use strict;
-use vars qw($VERSION @ISA);
+use warnings;
 
-use TAP::Object ();
-
-@ISA = 'TAP::Object';
+use base 'TAP::Object';
 
 BEGIN {
 
@@ -26,15 +24,15 @@ TAP::Parser::Result - Base class for TAP::Parser output objects
 
 =head1 VERSION
 
-Version 3.17_04
+Version 3.37_01
 
 =cut
 
-$VERSION = '3.17_04';
+our $VERSION = '3.37_01';
 
 =head1 SYNOPSIS
 
-  # abstract class - not meany to be used directly
+  # abstract class - not meant to be used directly
   # see TAP::Parser::ResultFactory for preferred usage
 
   # directly:
@@ -274,9 +272,8 @@ subclass L<TAP::Parser::Grammar> too, or else it'll never get used.
   package MyResult;
 
   use strict;
-  use vars '@ISA';
 
-  @ISA = 'TAP::Parser::Result';
+  use base 'TAP::Parser::Result';
 
   # register with the factory:
   TAP::Parser::ResultFactory->register_type( 'my_type' => __PACKAGE__ );
