@@ -1,12 +1,12 @@
 package TAP::Parser::Source;
 
 use strict;
-use vars qw($VERSION @ISA);
+use warnings;
 
-use TAP::Object ();
 use File::Basename qw( fileparse );
+use base 'TAP::Object';
 
-@ISA = qw(TAP::Object);
+use constant BLK_SIZE => 512;
 
 =head1 NAME
 
@@ -14,11 +14,11 @@ TAP::Parser::Source - a TAP source & meta data about it
 
 =head1 VERSION
 
-Version 3.17_04
+Version 3.37_01
 
 =cut
 
-$VERSION = '3.17_04';
+our $VERSION = '3.37_01';
 
 =head1 SYNOPSIS
 
@@ -288,8 +288,8 @@ sub assemble_meta {
                 $file->{lc_ext} = lc( $file->{ext} );
                 $file->{basename} .= $file->{ext} if $file->{ext};
 
-                if ( $file->{text} and $file->{read} ) {
-                    eval { $file->{shebang} = $self->_read_shebang($$raw); };
+                if ( !$file->{is_dir} && $file->{read} ) {
+                    eval { $file->{shebang} = $self->shebang($$raw); };
                     if ( my $e = $@ ) {
                         warn $e;
                     }
@@ -307,19 +307,38 @@ sub assemble_meta {
     return $meta;
 }
 
-sub _read_shebang {
-    my ( $self, $file ) = @_;
-    my $shebang;
-    local *TEST;
-    if ( open( TEST, $file ) ) {
-        $shebang = <TEST>;
-        chomp $shebang;
-        close(TEST) or die "Can't close $file. $!\n";
+=head3 C<shebang>
+
+Get the shebang line for a script file.
+
+  my $shebang = TAP::Parser::Source->shebang( $some_script );
+
+May be called as a class method
+
+=cut
+
+{
+
+    # Global shebang cache.
+    my %shebang_for;
+
+    sub _read_shebang {
+        my ( $class, $file ) = @_;
+        open my $fh, '<', $file or die "Can't read $file: $!\n";
+
+        # Might be a binary file - so read a fixed number of bytes.
+        my $got = read $fh, my ($buf), BLK_SIZE;
+        defined $got or die "I/O error: $!\n";
+        return $1 if $buf =~ /(.*)/;
+        return;
     }
-    else {
-        die "Can't open $file. $!\n";
+
+    sub shebang {
+        my ( $class, $file ) = @_;
+        $shebang_for{$file} = $class->_read_shebang($file)
+          unless exists $shebang_for{$file};
+        return $shebang_for{$file};
     }
-    return $shebang;
 }
 
 =head3 C<config_for>
