@@ -1,18 +1,17 @@
 package TAP::Parser::SourceHandler::Perl;
 
 use strict;
+use warnings;
 use Config;
-use vars qw($VERSION @ISA);
 
 use constant IS_WIN32 => ( $^O =~ /^(MS)?Win32$/ );
 use constant IS_VMS => ( $^O eq 'VMS' );
 
-use TAP::Parser::SourceHandler::Executable ();
 use TAP::Parser::IteratorFactory           ();
 use TAP::Parser::Iterator::Process         ();
-use TAP::Parser::Utils qw( split_shell );
+use Text::ParseWords qw(shellwords);
 
-@ISA = 'TAP::Parser::SourceHandler::Executable';
+use base 'TAP::Parser::SourceHandler::Executable';
 
 TAP::Parser::IteratorFactory->register_handler(__PACKAGE__);
 
@@ -22,11 +21,11 @@ TAP::Parser::SourceHandler::Perl - Stream TAP from a Perl executable
 
 =head1 VERSION
 
-Version 3.17_04
+Version 3.37_01
 
 =cut
 
-$VERSION = '3.17_04';
+our $VERSION = '3.37_01';
 
 =head1 SYNOPSIS
 
@@ -63,6 +62,7 @@ won't need to use this module directly.
 Only votes if $source looks like a file.  Casts the following votes:
 
   0.9  if it has a shebang ala "#!...perl"
+  0.75 if it has any shebang
   0.8  if it's a .t file
   0.9  if it's a .pl file
   0.75 if it's in a 't' directory
@@ -79,6 +79,12 @@ sub can_handle {
 
     if ( my $shebang = $file->{shebang} ) {
         return 0.9 if $shebang =~ /^#!.*\bperl/;
+
+        # We favour Perl as the interpreter for any shebang to preserve
+        # previous semantics: we used to execute everything via Perl and
+        # relied on it to pass the shebang off to the appropriate
+        # interpreter.
+        return 0.3;
     }
 
     return 0.8 if $file->{lc_ext} eq '.t';    # vote higher than Executable
@@ -121,6 +127,13 @@ Currently you need to write a plugin to get around this.
 
 =cut
 
+sub _autoflush_stdhandles {
+    my ($class) = @_;
+
+    $class->_autoflush( \*STDOUT );
+    $class->_autoflush( \*STDERR );
+}
+
 sub make_iterator {
     my ( $class, $source ) = @_;
     my $meta        = $source->meta;
@@ -129,10 +142,46 @@ sub make_iterator {
     $class->_croak("Cannot find ($perl_script)") unless $meta->{is_file};
 
     # TODO: does this really need to be done here?
-    $class->_autoflush( \*STDOUT );
-    $class->_autoflush( \*STDERR );
+    $class->_autoflush_stdhandles;
+
+    my ( $libs, $switches )
+      = $class->_mangle_switches(
+        $class->_filter_libs( $class->_switches($source) ) );
+
+    $class->_run( $source, $libs, $switches );
+}
+
+
+sub _has_taint_switch {
+    my( $class, $switches ) = @_;
+
+    my $has_taint = grep { $_ eq "-T" || $_ eq "-t" } @{$switches};
+    return $has_taint ? 1 : 0;
+}
+
+sub _mangle_switches {
+    my ( $class, $libs, $switches ) = @_;
+
+    # Taint mode ignores environment variables so we must retranslate
+    # PERL5LIB as -I switches and place PERL5OPT on the command line
+    # in order that it be seen.
+    if ( $class->_has_taint_switch($switches) ) {
+        my @perl5lib = defined $ENV{PERL5LIB} ? split /$Config{path_sep}/, $ENV{PERL5LIB} : ();
+        return (
+            $libs,
+            [   @{$switches},
+                $class->_libs2switches([@$libs, @perl5lib]),
+                defined $ENV{PERL5OPT} ? shellwords( $ENV{PERL5OPT} ) : ()
+            ],
+        );
+    }
+
+    return ( $libs, $switches );
+}
+
+sub _filter_libs {
+    my ( $class, @switches ) = @_;
 
-    my @switches = $class->_switches($source);
     my $path_sep = $Config{path_sep};
     my $path_re  = qr{$path_sep};
 
@@ -147,24 +196,31 @@ sub make_iterator {
     my @libs;
     my @filtered_switches;
     for (@switches) {
-        if ( !/$path_re/ && / ^ ['"]? -I ['"]? (.*?) ['"]? $ /x ) {
+        if ( !/$path_re/ && m/ ^ ['"]? -I ['"]? (.*?) ['"]? $ /x ) {
             push @libs, $1;
         }
         else {
             push @filtered_switches, $_;
         }
     }
-    @switches = @filtered_switches;
+
+    return \@libs, \@filtered_switches;
+}
+
+sub _iterator_hooks {
+    my ( $class, $source, $libs, $switches ) = @_;
 
     my $setup = sub {
-        if (@libs) {
-            $ENV{PERL5LIB}
-              = join( $path_sep, grep {defined} @libs, $ENV{PERL5LIB} );
+        if ( @{$libs} and !$class->_has_taint_switch($switches) ) {
+            $ENV{PERL5LIB} = join(
+                $Config{path_sep}, grep {defined} @{$libs},
+                $ENV{PERL5LIB}
+            );
         }
     };
 
-    # Cargo culted from comments seen elsewhere about VMS / environment
-    # variables. I don't know if this is actually necessary.
+    # VMS environment variables aren't guaranteed to reset at the end of
+    # the process, so we need to put PERL5LIB back.
     my $previous = $ENV{PERL5LIB};
     my $teardown = sub {
         if ( defined $previous ) {
@@ -175,19 +231,25 @@ sub make_iterator {
         }
     };
 
-    # Taint mode ignores environment variables so we must retranslate
-    # PERL5LIB as -I switches and place PERL5OPT on the command line
-    # in order that it be seen.
-    if ( grep { $_ eq "-T" || $_ eq "-t" } @switches ) {
-        push @switches, $class->_libs2switches(@libs);
-        push @switches, split_shell( $ENV{PERL5OPT} );
-    }
+    return ( $setup, $teardown );
+}
 
-    my @command = $class->_get_command_for_switches( $source, @switches )
+sub _run {
+    my ( $class, $source, $libs, $switches ) = @_;
+
+    my @command = $class->_get_command_for_switches( $source, $switches )
       or $class->_croak("No command found!");
 
+    my ( $setup, $teardown ) = $class->_iterator_hooks( $source, $libs, $switches );
+
+    return $class->_create_iterator( $source, \@command, $setup, $teardown );
+}
+
+sub _create_iterator {
+    my ( $class, $source, $command, $setup, $teardown ) = @_;
+
     return TAP::Parser::Iterator::Process->new(
-        {   command  => \@command,
+        {   command  => $command,
             merge    => $source->merge,
             setup    => $setup,
             teardown => $teardown,
@@ -196,20 +258,20 @@ sub make_iterator {
 }
 
 sub _get_command_for_switches {
-    my ( $class, $source, @switches ) = @_;
+    my ( $class, $source, $switches ) = @_;
     my $file    = ${ $source->raw };
     my @args    = @{ $source->test_args || [] };
     my $command = $class->get_perl;
 
    # XXX don't need to quote if we treat the parts as atoms (except maybe vms)
    #$file = qq["$file"] if ( $file =~ /\s/ ) && ( $file !~ /^".*"$/ );
-    my @command = ( $command, @switches, $file, @args );
+    my @command = ( $command, @{$switches}, $file, @args );
     return @command;
 }
 
 sub _libs2switches {
     my $class = shift;
-    return map {"-I$_"} grep {$_} @_;
+    return map {"-I$_"} grep {$_} @{ $_[0] };
 }
 
 =head3 C<get_taint>
@@ -235,7 +297,6 @@ sub get_taint {
 sub _switches {
     my ( $class, $source ) = @_;
     my $file     = ${ $source->raw };
-    my @args     = @{ $source->test_args || [] };
     my @switches = @{ $source->switches || [] };
     my $shebang  = $source->meta->{file}->{shebang};
     return unless defined $shebang;
@@ -263,7 +324,7 @@ Gets the version of Perl currently running the test suite.
 sub get_perl {
     my $class = shift;
     return $ENV{HARNESS_PERL} if defined $ENV{HARNESS_PERL};
-    return Win32::GetShortPathName($^X) if IS_WIN32;
+    return qq["$^X"] if IS_WIN32 && ( $^X =~ /[^\w\.\/\\]/ );
     return $^X;
 }
 
@@ -280,11 +341,10 @@ Please see L<TAP::Parser/SUBCLASSING> for a subclassing overview.
   package MyPerlSourceHandler;
 
   use strict;
-  use vars '@ISA';
 
   use TAP::Parser::SourceHandler::Perl;
 
-  @ISA = qw( TAP::Parser::SourceHandler::Perl );
+  use base 'TAP::Parser::SourceHandler::Perl';
 
   # use the version of perl from the shebang line in the test file
   sub get_perl {
