@@ -1,42 +1,28 @@
 package Test::Harness;
 
-require 5.00405;
+use 5.006;
 
 use strict;
+use warnings;
 
 use constant IS_WIN32 => ( $^O =~ /^(MS)?Win32$/ );
 use constant IS_VMS => ( $^O eq 'VMS' );
 
-use TAP::Harness              ();
-use TAP::Parser::Aggregator   ();
-use TAP::Parser::Source::Perl ();
+use TAP::Harness                     ();
+use TAP::Parser::Aggregator          ();
+use TAP::Parser::Source              ();
+use TAP::Parser::SourceHandler::Perl ();
 
-use TAP::Parser::Utils qw( split_shell );
+use Text::ParseWords qw(shellwords);
 
 use Config;
-use Exporter;
-
-# TODO: Emulate at least some of these
-use vars qw(
-  $VERSION
-  @ISA @EXPORT @EXPORT_OK
-  $Verbose $Switches $Debug
-  $verbose $switches $debug
-  $Columns
-  $Color
-  $Directives
-  $Timer
-  $Strap
-  $HarnessSubclass
-  $has_time_hires
-  $IgnoreExit
-);
+use base 'Exporter';
 
 # $ML $Last_ML_Print
 
 BEGIN {
     eval q{use Time::HiRes 'time'};
-    $has_time_hires = !$@;
+    our $has_time_hires = !$@;
 }
 
 =head1 NAME
@@ -45,11 +31,11 @@ Test::Harness - Run Perl standard test scripts with statistics
 
 =head1 VERSION
 
-Version 3.17_04
+Version 3.37_01
 
 =cut
 
-$VERSION = '3.17_04';
+our $VERSION = '3.37_01';
 
 # Backwards compatibility for exportable variable names.
 *verbose  = *Verbose;
@@ -66,18 +52,17 @@ END {
     delete $ENV{HARNESS_VERSION};
 }
 
-@ISA       = ('Exporter');
-@EXPORT    = qw(&runtests);
-@EXPORT_OK = qw(&execute_tests $verbose $switches);
+our @EXPORT    = qw(&runtests);
+our @EXPORT_OK = qw(&execute_tests $verbose $switches);
 
-$Verbose = $ENV{HARNESS_VERBOSE} || 0;
-$Debug   = $ENV{HARNESS_DEBUG}   || 0;
-$Switches = '-w';
-$Columns = $ENV{HARNESS_COLUMNS} || $ENV{COLUMNS} || 80;
+our $Verbose = $ENV{HARNESS_VERBOSE} || 0;
+our $Debug   = $ENV{HARNESS_DEBUG}   || 0;
+our $Switches = '-w';
+our $Columns = $ENV{HARNESS_COLUMNS} || $ENV{COLUMNS} || 80;
 $Columns--;    # Some shells have trouble with a full line of text.
-$Timer      = $ENV{HARNESS_TIMER}       || 0;
-$Color      = $ENV{HARNESS_COLOR}       || 0;
-$IgnoreExit = $ENV{HARNESS_IGNORE_EXIT} || 0;
+our $Timer      = $ENV{HARNESS_TIMER}       || 0;
+our $Color      = $ENV{HARNESS_COLOR}       || 0;
+our $IgnoreExit = $ENV{HARNESS_IGNORE_EXIT} || 0;
 
 =head1 SYNOPSIS
 
@@ -119,8 +104,8 @@ one of the messages in the DIAGNOSTICS section.
 
 sub _has_taint {
     my $test = shift;
-    return TAP::Parser::Source::Perl->get_taint(
-        TAP::Parser::Source::Perl->shebang($test) );
+    return TAP::Parser::SourceHandler::Perl->get_taint(
+        TAP::Parser::Source->shebang($test) );
 }
 
 sub _aggregate {
@@ -133,7 +118,7 @@ sub _aggregate {
     _aggregate_tests( $harness, $aggregate, @tests );
 }
 
-# Make sure the child seens all the extra junk in @INC
+# Make sure the child sees all the extra junk in @INC
 sub _apply_extra_INC {
     my $harness = shift;
 
@@ -162,6 +147,7 @@ sub runtests {
     my $harness   = _new_harness();
     my $aggregate = TAP::Parser::Aggregator->new();
 
+    local $ENV{PERL_USE_UNSAFE_INC} = 1 if not exists $ENV{PERL_USE_UNSAFE_INC};
     _aggregate( $harness, $aggregate, @tests );
 
     $harness->formatter->summary($aggregate);
@@ -208,7 +194,7 @@ sub _new_harness {
     my $sub_args = shift || {};
 
     my ( @lib, @switches );
-    my @opt = split_shell( $Switches, $ENV{HARNESS_PERL_SWITCHES} );
+    my @opt = map { shellwords($_) } grep { defined } $Switches, $ENV{HARNESS_PERL_SWITCHES};
     while ( my $opt = shift @opt ) {
         if ( $opt =~ /^ -I (.*) $ /x ) {
             push @lib, length($1) ? $1 : shift @opt;
@@ -226,7 +212,7 @@ sub _new_harness {
 
     my $args = {
         timer       => $Timer,
-        directives  => $Directives,
+        directives  => our $Directives,
         lib         => \@lib,
         switches    => \@switches,
         color       => $Color,
@@ -237,6 +223,7 @@ sub _new_harness {
     $args->{stdout} = $sub_args->{out}
       if exists $sub_args->{out};
 
+    my $class = $ENV{HARNESS_SUBCLASS} || 'TAP::Harness';
     if ( defined( my $env_opt = $ENV{HARNESS_OPTIONS} ) ) {
         for my $opt ( split /:/, $env_opt ) {
             if ( $opt =~ /^j(\d*)$/ ) {
@@ -245,13 +232,22 @@ sub _new_harness {
             elsif ( $opt eq 'c' ) {
                 $args->{color} = 1;
             }
+            elsif ( $opt =~ m/^f(.*)$/ ) {
+                my $fmt = $1;
+                $fmt =~ s/-/::/g;
+                $args->{formatter_class} = $fmt;
+            }
+            elsif ( $opt =~ m/^a(.*)$/ ) {
+                my $archive = $1;
+                $class = "TAP::Harness::Archive";
+                $args->{archive} = $archive;
+            }
             else {
                 die "Unknown HARNESS_OPTIONS item: $opt\n";
             }
         }
     }
 
-    my $class = $ENV{HARNESS_SUBCLASS} || 'TAP::Harness';
     return TAP::Harness->_construct( $class, $args );
 }
 
@@ -270,7 +266,7 @@ sub _filtered_inc {
     elsif (IS_WIN32) {
 
         # Lose any trailing backslashes in the Win32 paths
-        s/[\\\/]+$// foreach @inc;
+        s/[\\\/]+$// for @inc;
     }
 
     my @default_inc = _default_inc();
@@ -307,7 +303,7 @@ sub _filtered_inc {
         my $perl = $ENV{HARNESS_PERL} || $^X;
 
         # Avoid using -l for the benefit of Perl 6
-        chomp( @inc = `$perl -e "print join qq[\\n], \@INC, q[]"` );
+        chomp( @inc = `"$perl" -e "print join qq[\\n], \@INC, q[]"` );
         return @inc;
     }
 }
@@ -359,6 +355,7 @@ sub execute_tests {
         }
     );
 
+    local $ENV{PERL_USE_UNSAFE_INC} = 1 if not exists $ENV{PERL_USE_UNSAFE_INC};
     _aggregate( $harness, $aggregate, @{ $args{tests} } );
 
     $tot{bench} = $aggregate->elapsed;
@@ -508,6 +505,17 @@ This is the version of C<Test::Harness>.
 
 =over 4
 
+=item C<HARNESS_PERL_SWITCHES>
+
+Setting this adds perl command line switches to each test file run.
+
+For example, C<HARNESS_PERL_SWITCHES=-T> will turn on taint mode.
+C<HARNESS_PERL_SWITCHES=-MDevel::Cover> will run C<Devel::Cover> for
+each test.
+
+C<-w> is always set.  You can turn this off in the test with C<BEGIN {
+$^W = 0 }>.
+
 =item C<HARNESS_TIMER>
 
 Setting this to true will make the harness display the number of
@@ -530,20 +538,40 @@ Provide additional options to the harness. Currently supported options are:
 
 Run <n> (default 9) parallel jobs.
 
-=item C<< f >>
+=item C<< c >>
 
-Use forked parallelism.
+Try to color output. See L<TAP::Formatter::Base/"new">.
+
+=item C<< a<file.tgz> >>
+
+Will use L<TAP::Harness::Archive> as the harness class, and save the TAP to
+C<file.tgz>
+
+=item C<< fPackage-With-Dashes >>
+
+Set the formatter_class of the harness being run. Since the C<HARNESS_OPTIONS>
+is seperated by C<:>, we use C<-> instead.
 
 =back
 
 Multiple options may be separated by colons:
 
-    HARNESS_OPTIONS=j9:f make test
+    HARNESS_OPTIONS=j9:c make test
 
 =item C<HARNESS_SUBCLASS>
 
 Specifies a TAP::Harness subclass to be used in place of TAP::Harness.
 
+=item C<HARNESS_SUMMARY_COLOR_SUCCESS>
+
+Determines the L<Term::ANSIColor> for the summary in case it is successful.
+This color defaults to C<'green'>.
+
+=item C<HARNESS_SUMMARY_COLOR_FAIL>
+
+Determines the L<Term::ANSIColor> for the failure in case it is successful.
+This color defaults to C<'red'>.
+
 =back
 
 =head1 Taint Mode
@@ -552,10 +580,9 @@ Normally when a Perl program is run in taint mode the contents of the
 C<PERL5LIB> environment variable do not appear in C<@INC>.
 
 Because C<PERL5LIB> is often used during testing to add build
-directories to C<@INC> C<Test::Harness> (actually
-L<TAP::Parser::Source::Perl>) passes the names of any directories found
-in C<PERL5LIB> as -I switches. The net effect of this is that
-C<PERL5LIB> is honoured even in taint mode.
+directories to C<@INC> C<Test::Harness> passes the names of any
+directories found in C<PERL5LIB> as -I switches. The net effect of this
+is that C<PERL5LIB> is honoured even in taint mode.
 
 =head1 SEE ALSO
 
@@ -584,7 +611,7 @@ module is based) has this attribution:
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2007-2008, Andy Armstrong C<< <andy@hexten.net> >>. All rights reserved.
+Copyright (c) 2007-2011, Andy Armstrong C<< <andy@hexten.net> >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
